@@ -12,6 +12,7 @@ REGION_LEVELS = {
     'coordinate': 9
 }
 
+# Note: Separate id and name using tab "\t" instead of "space"
 CLIMATE_ITEMS_STR = """item_id	name
 9126	Bulk density (fine earth) at 100 cm deep
 9123	Bulk density (fine earth) at 15 cm deep
@@ -67,6 +68,7 @@ CLIMATE_ITEMS_STR = """item_id	name
 16496	NDVI on soy, area-weighted
 21532	NDVI on spring wheat, area-weighted
 20681	NDVI on winter wheat, area-weighted
+10081	Precipitation
 2039	Rainfall
 9117	Saturated water content at 100 cm deep
 9114	Saturated water content at 15 cm deep
@@ -149,10 +151,12 @@ CLIMATE_ITEMS_STR = """item_id	name
 8813	Soil water storage greater than 150 cm deep
 8832	Soil water storage in the root zone
 8818	Soil water storage in the total soil profile
+10089	Temperature
 321	Vegetation (NDVI)
 7828	Water areas""".split('\n')[1:]
 CLIMATE_ITEMS = {int(line.split('\t')[0]): line.split('\t')[1] for line in CLIMATE_ITEMS_STR}
 
+# Note: Separate id and name using tab "\t" instead of "space"
 CLIMATE_METRICS_STR = """metric_id	name
 15852116	Aspect
 15852972	Atmospheric Greenhouse Gas Concentration
@@ -182,6 +186,11 @@ CLIMATE_METRICS_STR = """metric_id	name
 2110132	Precipitation difference from 10-yr trailing mean
 2110133	Precipitation difference from 5-yr trailing mean
 2100031	Precipitation Quantity
+15853528	Precipitation Quantity, 95th Percentile of Wet Day Daily, SSP119
+15853529	Precipitation Quantity, 95th Percentile of Wet Day Daily, SSP126
+15853530	Precipitation Quantity, 95th Percentile of Wet Day Daily, SSP245
+15853531	Precipitation Quantity, 95th Percentile of Wet Day Daily, SSP370
+15853532	Precipitation Quantity, 95th Percentile of Wet Day Daily, SSP585
 15853046	Recurrence
 15853045	Seasonality
 15852115	Slope
@@ -193,9 +202,17 @@ CLIMATE_METRICS_STR = """metric_id	name
 15750042	Texture
 15852181	Time Length
 15853414	Variation of Precipitation
-15852979	Variation of Precipitation Difference from 10-yr Mean
+15853535	Variation of Precipitation, SSP119
+15853536	Variation of Precipitation, SSP126
+15853537	Variation of Precipitation, SSP245
+15853538	Variation of Precipitation, SSP370
+15853539	Variation of Precipitation, SSP585
 15853416	Variation of Temperature
-15852977	Variation of Temperature Difference from 10-yr Mean
+15853541	Variation of Temperature, SSP119
+15853542	Variation of Temperature, SSP126
+15853543	Variation of Temperature, SSP245
+15853544	Variation of Temperature, SSP370
+15853545	Variation of Temperature, SSP585
 70029	Vegetation Indices
 430132	Vegetation Indices 10-yr mean (2001-2010)
 430131	Vegetation Indices 10-yr trailing mean
@@ -207,8 +224,9 @@ CLIMATE_METRICS_STR = """metric_id	name
 15852328	Volatility-adjusted YOY Change, Retail Prices by Mass (percent)
 15852331	Volatility-adjusted YOY Change, Wholesale Prices by Count (percent)
 15852330	Volatility-adjusted YOY Change, Wholesale Prices by Mass (percent)""".split('\n')[1:]
+
 CLIMATE_METRICS = {int(line.split('\t')[0]): line.split('\t')[1] for line in CLIMATE_METRICS_STR}
 
-CLIMATE_SOURCES = [3,20,22,26,35,43,44,78,80,82,87,89,97,105,112,124,126,133,145,150,152,163,167,172,192,190,189,191,178,187,188]
+CLIMATE_SOURCES = [3,20,22,26,35,43,44,78,80,82,87,89,97,105,112,124,126,133,145,150,152,163,167,172,192,190,189,191,178,187,188,239,241]
 CMIP6_SOURCES = [178, 189, 190, 191, 192]
 
